@@ -92,42 +92,43 @@ describe 'horizon' do
     context 'with overridden parameters' do
       before do
         params.merge!({
-          :cache_backend                => 'horizon.backends.memcached.HorizonMemcached',
-          :cache_options                => {'SOCKET_TIMEOUT' => 1,'SERVER_RETRIES' => 1,'DEAD_RETRY' => 1},
-          :cache_server_ip              => '10.0.0.1',
-          :django_session_engine        => 'django.contrib.sessions.backends.cache',
-          :keystone_default_role        => 'SwiftOperator',
-          :keystone_url                 => 'https://keystone.example.com:4682',
-          :ssl_no_verify                => true,
-          :log_handler                  => 'syslog',
-          :log_level                    => 'DEBUG',
-          :openstack_endpoint_type      => 'internalURL',
-          :secondary_endpoint_type      => 'ANY-VALUE',
-          :django_debug                 => true,
-          :api_result_limit             => 4682,
-          :compress_offline             => false,
-          :hypervisor_options           => {'can_set_mount_point' => false, 'can_set_password' => true },
-          :cinder_options               => {'enable_backup' => true },
-          :keystone_options             => {'name' => 'native', 'can_edit_user' => true, 'can_edit_group' => true, 'can_edit_project' => true, 'can_edit_domain' => false, 'can_edit_role' => false},
-          :neutron_options              => {'enable_lb' => true, 'enable_firewall' => true, 'enable_quotas' => false, 'enable_security_group' => false, 'enable_vpn' => true,
+          :cache_backend                  => 'horizon.backends.memcached.HorizonMemcached',
+          :cache_options                  => {'SOCKET_TIMEOUT' => 1,'SERVER_RETRIES' => 1,'DEAD_RETRY' => 1},
+          :cache_server_ip                => '10.0.0.1',
+          :django_session_engine          => 'django.contrib.sessions.backends.cache',
+          :keystone_default_role          => 'SwiftOperator',
+          :keystone_url                   => 'https://keystone.example.com:4682',
+          :ssl_no_verify                  => true,
+          :log_handler                    => 'syslog',
+          :log_level                      => 'DEBUG',
+          :openstack_endpoint_type        => 'internalURL',
+          :secondary_endpoint_type        => 'ANY-VALUE',
+          :django_debug                   => true,
+          :api_result_limit               => 4682,
+          :compress_offline               => false,
+          :hypervisor_options             => {'can_set_mount_point' => false, 'can_set_password' => true },
+          :cinder_options                 => {'enable_backup' => true },
+          :keystone_options               => {'name' => 'native', 'can_edit_user' => true, 'can_edit_group' => true, 'can_edit_project' => true, 'can_edit_domain' => false, 'can_edit_role' => false},
+          :neutron_options                => {'enable_lb' => true, 'enable_firewall' => true, 'enable_quotas' => false, 'enable_security_group' => false, 'enable_vpn' => true,
                                             'enable_distributed_router' => false, 'enable_ha_router' => false, 'profile_support' => 'cisco',
                                             'supported_provider_types' => ['flat', 'vxlan'], 'supported_vnic_types' => ['*'], 'default_ipv4_subnet_pool_label' => 'None', },
-          :file_upload_temp_dir         => '/var/spool/horizon',
-          :secure_cookies               => true,
-          :api_versions                 => {'identity' => 2.0},
-          :keystone_multidomain_support => true,
-          :keystone_default_domain      => 'domain.tld',
-          :overview_days_range          => 1,
-          :session_timeout              => 1800,
-          :timezone                     => 'Asia/Shanghai',
-          :available_themes             => [
+          :file_upload_temp_dir           => '/var/spool/horizon',
+          :secure_cookies                 => true,
+          :api_versions                   => {'identity' => 2.0},
+          :keystone_multidomain_support   => true,
+          :keystone_default_domain        => 'domain.tld',
+          :overview_days_range            => 1,
+          :session_timeout                => 1800,
+          :timezone                       => 'Asia/Shanghai',
+          :available_themes               => [
             { 'name' => 'default', 'label' => 'Default', 'path' => 'themes/default' },
             { 'name' => 'material', 'label' => 'Material', 'path' => 'themes/material' },
           ],
-          :default_theme                => 'default',
-          :password_autocomplete        => 'on',
-          :images_panel                 => 'angular',
-          :password_retrieve            => true,
+          :default_theme                  => 'default',
+          :password_autocomplete          => 'on',
+          :images_panel                   => 'angular',
+          :password_retrieve              => true,
+          :enable_secure_proxy_ssl_header => true,
         })
       end
 
@@ -135,6 +136,7 @@ describe 'horizon' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
           'DEBUG = True',
           "ALLOWED_HOSTS = ['*', ]",
+          "SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')",
           'CSRF_COOKIE_SECURE = True',
           'SESSION_COOKIE_SECURE = True',
           "  'identity': 2.0,",
@@ -223,7 +225,6 @@ describe 'horizon' do
 
       it {
         is_expected.to contain_package('python-memcache').with(
-          :ensure => 'present',
           :tag    => ['openstack']
          )
       }
@@ -427,6 +428,20 @@ describe 'horizon' do
         ])
       end
     end
+
+    context 'with enforce password check enabled' do
+      before do
+        params.merge!({
+          :enforce_password_check => true
+        })
+      end
+
+      it 'enforce_password_check is configured' do
+        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
+          'HORIZON_CONFIG["enforce_password_check"] = True',
+        ])
+      end
+    end
   end
 
   shared_examples_for 'horizon on RedHat' do
